OakVar

auto GRCh38/hg38 GRCh37/hg19 GRCh36/hg18
auto

Click to upload or drag and drop input files

or

Select optional report files to generate.

Scroll down or click to select analysis modules

Search
Search
Selected analysis modules

| Name | Input | Submitted | State | Note | View
--- | --- | --- | --- | --- | --- | ---

Showing 1 to 10 of 97 results

Search
Search

- ### ClinVar

    ClinVar is an archive of reports of the relationships among human variations and phenotypes, with supporting evidence.
    Installed
  Details...
  Uninstall

### System not ready

OakVar server is not running or it is having a problem. Please contact your system administrator.

###

###

System update available

Update available

By Category

Sort by
There are missing system modules which OakVar needs.
Click this button to install them:
System updates in progress...
System configuration file:
Jobs dir:
Modules dir:
Limit the sum of input file sizes to: MB
Maximum number of concurrent jobs:
Maximum number of concurrent annotators per job:

Uploading input file(s)...
Updating store information...
Choose a report type: